@@ -1,5 +1,4 @@
 """Provides tools for managing the Azure Database service"""
-
 from devops_toolset.core.app import App
 from devops_toolset.core.CommandsCore import CommandsCore
 from devops_toolset.core.LiteralsCore import LiteralsCore
@@ -12,6 +11,7 @@ import devops_toolset.project_types.azure.common as common
 import json
 import logging
 import re
+import pathlib
 
 app: App = App()
 literals = LiteralsCore([AzureLiterals])
@@ -76,6 +76,11 @@ def execute_mysql_flexible_server_sql_script(admin_user: str, admin_password: st
     if file_path is None and query is None:
         raise ValueError(literals.get("azure_cli_db_mysql_flexible_server_execute_file_query_parameters_error"))
 
+    # If file path doesn't exist, then return without doing anything
+    if not pathlib.Path.exists(file_path):
+        logging.warning(literals.get("azure_mysql_script_not_found").format(file_path=file_path))
+        return
+
     # Install rdbms-connect Azure CLI extension if not already installed
     az_extension: str = "rdbms-connect"
     if not common.is_cli_extension_installed(az_extension):
