@@ -20,5 +20,9 @@ class Commands(ValueDictsBase):
         "git_tag_check": "git {auth} ls-remote {remote_name} \"refs/tags/{tag_name}\"",
         "git_tag_delete": "git tag -d {tag_name}",
         "public_ip_address_service_url": "http://checkip.dyndns.org",
-        "git_auth": "-c http.extraheader=\"AUTHORIZATION: {auth_header}\""
+        "git_auth": "-c http.extraheader=\"AUTHORIZATION: {auth_header}\"",
+        "svn_add": "svn add \"{files_glob}\"",
+        "svn_checkin": "svn ci -m \"{comment}\" --username {username} --password {password}",
+        "svn_checkout": "svn co \"{url}\" \"{local_path}\"",
+        "svn_copy": "svn cp \"{origin}\" \"{destination}\""
     }
